@@ -2,10 +2,7 @@ import click
 import yaml
 import os
 from dnastack.cli import *
-import dnastack
-import ssl
-
-ssl._create_default_https_context = ssl._create_stdlib_context
+from dnastack.constants import __version__
 
 
 def load_config_from_file(ctx):
@@ -32,14 +29,22 @@ def load_config_from_file(ctx):
 
 
 @click.group()
+@click.version_option(__version__, message="%(version)s")
 def dnastack():
     load_config_from_file(click.get_current_context())
 
 
+@dnastack.command(name="version")
+def get_version():
+    click.echo(__version__)
+
+
 dnastack.add_command(dataconnect_commands.dataconnect)
 dnastack.add_command(config_commands.config)
 dnastack.add_command(file_commands.files)
+dnastack.add_command(auth_commands.auth)
 dnastack.add_command(collections_commands.collections)
+dnastack.add_command(wes_commands.wes)
 
 if __name__ == "__main__":
     dnastack.main(prog_name="dnastack")
