@@ -23,17 +23,24 @@ def dataconnect(ctx):
     show_default=True,
 )
 def query(ctx, q, download, raw, format="json"):
-    click.echo(
-        dataconnect_client.query(
-            get_config(ctx, "data-connect-url", str),
-            q,
-            download,
-            "csv"
-            if raw
-            else format,  # we need to make the -r/--raw command backwards compatible so override -f if -r is used
-            raw,
+    try:
+        click.echo(
+            dataconnect_client.query(
+                get_config(ctx, "data-connect-url", str),
+                q,
+                download,
+                "csv"
+                if raw
+                else format,  # we need to make the -r/--raw command backwards compatible so override -f if -r is used
+                raw,
+            ),
+            nl=False,
         )
-    )
+    except Exception as e:
+        click.secho(
+            f"Unable to query [{get_config(ctx, 'data-connect-url', str)}]: {e}"
+        )
+        sys.exit(1)
 
 
 dataconnect.add_command(tables_commands.tables)
