@@ -2,3 +2,6 @@ from dnastack.constants import *
 from .files_client import *
 from .dataconnect_client import *
 from .collections_client import *
+from .auth_client import *
+from .utils import *
+from .wes_client import *
