@@ -72,7 +72,13 @@ def exit_download(url, code, exit_codes):
         exit_code_lock.release()
 
 
-def download_file(url, output_dir, out: Optional[list] = None, exit_codes=None):
+def download_file(
+    url,
+    output_dir,
+    oauth_token: Optional[dict] = None,
+    out: Optional[list] = None,
+    exit_codes=None,
+):
 
     http = urllib3.PoolManager()
     chunk_size = 1024
@@ -97,9 +103,11 @@ def download_file(url, output_dir, out: Optional[list] = None, exit_codes=None):
                     "There was an error getting object info from the DRS Client",
                     fg="red",
                 )
+                http.clear()
                 exit_download(url, 1, exit_codes)
                 return
         except Exception as e:
+            http.clear()
             exit_download(url, 1, exit_codes)
             return
 
@@ -114,6 +122,7 @@ def download_file(url, output_dir, out: Optional[list] = None, exit_codes=None):
                             )
                         except HTTPError as e:
                             click.echo(e)
+                            http.clear()
                             exit_download(url, 1, exit_codes)
                         download_url = object_access["url"]
                         break
@@ -127,6 +136,7 @@ def download_file(url, output_dir, out: Optional[list] = None, exit_codes=None):
             return  # next page token, just return
     else:
         click.secho(f"[{url}] is not a valid DRS url", fg="red")
+        http.clear()
         exit_download(url, 1, exit_codes)
         return
 
@@ -134,6 +144,7 @@ def download_file(url, output_dir, out: Optional[list] = None, exit_codes=None):
         download_stream = http.request("GET", download_url, preload_content=False)
     except:
         click.secho("There was an error downloading " + download_url, fg="red")
+        http.clear()
         exit_download(url, 1, exit_codes)
         return
 
@@ -152,12 +163,14 @@ def download_file(url, output_dir, out: Optional[list] = None, exit_codes=None):
                 for chunk in file_stream:
                     dest.write(chunk)
                     download_progress.update(chunk_size)
+    http.clear()
     exit_download(url, 0, exit_codes)
 
 
 def download_files(
     urls,
     output_dir=downloads_directory,
+    oauth_token: Optional[dict] = None,
     out=None,
 ):
     download_threads = []
@@ -171,6 +184,7 @@ def download_files(
             target=download_file(
                 url,
                 output_dir,
+                oauth_token,
                 out=out,
                 exit_codes=exit_codes,
             ),
